#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const utils_1 = require("./utils");
const lsp_connection_1 = require("./lsp-connection");
const lsp = require("vscode-languageserver");
const program = new commander_1.Command('typescript-language-server')
    .version(require('../package.json').version)
    .option('--stdio', 'use stdio')
    .option('--node-ipc', 'use node-ipc')
    .option('--log-level', 'A number indicating the log level (4 = log, 3 = info, 2 = warn, 1 = error). Defaults to `3`.')
    .option('--socket <port>', 'use socket. example: --socket=5000')
    .option('--tsserver-logFile <tsServerLogFile>', 'Specify a tsserver log file. example: --tsServerLogFile=ts-logs.txt')
    .option('--tsserver-path <path>', `Specifiy path to tsserver. example: --tsserver-path=${utils_1.getTsserverExecutable()}`)
    .parse(process.argv);
if (!(program.stdio || program.socket || program['node-ipc'])) {
    console.error('Connection type required (stdio, node-ipc, socket). Refer to --help for more details.');
    process.exit(1);
}
let logLevel = program['leg-level'];
if (logLevel && (logLevel < 1 || logLevel > 4)) {
    console.error('Invalid `--log-level ' + logLevel + '`. Falling back to `info` level.');
    logLevel = undefined;
}
lsp_connection_1.createLspConnection({
    tsserverPath: program.path,
    tsserverLogFile: program.tsServerLogFile,
    showMessageLevel: logLevel || lsp.MessageType.Info
}).listen();
//# sourceMappingURL=cli.js.map